@@ -193,7 +193,9 @@ PJ *CONVERSION(axisswap,0) {
             }
 
         /* read axes numbers and signs */
-        for ( s = order, n = 0; *s != '\0' && n < 4; ) {
+        s = order;
+        n = 0;
+        while ( *s != '\0' && n < 4 ) {
             Q->axis[n] = abs(atoi(s))-1;
             if (Q->axis[n] > 3) {
                 proj_log_error(P, "axisswap: invalid axis '%d'", Q->axis[n]);
