@@ -1,6 +1,8 @@
 #define PJ_LIB__
-# include	<errno.h>
-# include	"projects.h"
+#include <math.h>
+
+#include "projects.h"
+
 PROJ_HEAD(boggs, "Boggs Eumorphic") "\n\tPCyl., no inv., Sph.";
 # define NITER	20
 # define EPS	1e-7
@@ -39,5 +41,3 @@ PJ *PROJECTION(boggs) {
     P->fwd = s_forward;
     return P;
 }
-
-
