@@ -1,6 +1,9 @@
 #define PJ_LIB__
+
 #include <errno.h>
-#include <proj.h>
+#include <math.h>
+
+#include "proj.h"
 #include "projects.h"
 
 typedef struct { double r, Az; } VECT;
@@ -50,7 +53,7 @@ static double lc(projCtx ctx, double b,double c,double a) {
 
 
 static XY s_forward (LP lp, PJ *P) {           /* Spheroidal, forward */
-    XY xy = {0.0,0.0};
+    XY xy;
     struct pj_opaque *Q = P->opaque;
     double sinphi, cosphi, a;
     VECT v[3];
@@ -134,5 +137,3 @@ PJ *PROJECTION(chamb) {
 
     return P;
 }
-
-
