@@ -1,5 +1,8 @@
 #define PJ_LIB__
-#include <projects.h>
+
+#include <math.h>
+
+#include "projects.h"
 
 PROJ_HEAD(gall, "Gall (Gall Stereographic)") "\n\tCyl, Sph";
 
@@ -39,5 +42,3 @@ PJ *PROJECTION(gall) {
 
     return P;
 }
-
-
