@@ -9,7 +9,7 @@
 #include "projects.h"
 
 PROJ_HEAD(merc, "Mercator") "\n\tCyl, Sph&Ell\n\tlat_ts=";
-PROJ_HEAD(webmerc, "Web Mercator / Pseudo Mercator") "\n\tCyl, Sph\n\t";
+PROJ_HEAD(webmerc, "Web Mercator / Pseudo Mercator") "\n\tCyl, Ell\n\t";
 
 #define EPS10 1.e-10
 static double logtanpfpim1(double x) {       /* log(tan(x/2 + M_FORTPI)) */
@@ -57,7 +57,7 @@ static LP e_inverse (XY xy, PJ *P) {          /* Ellipsoidal, inverse */
 
 static LP s_inverse (XY xy, PJ *P) {           /* Spheroidal, inverse */
     LP lp = {0.0,0.0};
-    lp.phi = M_HALFPI - 2. * atan(exp(-xy.y / P->k0));
+    lp.phi = atan(sinh(xy.y / P->k0));
     lp.lam = xy.x / P->k0;
     return lp;
 }
@@ -92,15 +92,9 @@ PJ *PROJECTION(merc) {
 
 PJ *PROJECTION(webmerc) {
 
-    /* Overriding k_0, lat_0 and lon_0 with fixed parameters */
+    /* Overriding k_0 with fixed parameter */
     P->k0 = 1.0;
-    P->phi0 = 0.0;
-    P->lam0 = 0.0;
 
-    P->b = P->a;
-    /* Clean up the ellipsoidal parameters to reflect the sphere */
-    P->es = P->e = P->f = 0;
-    pj_calc_ellipsoid_params (P, P->a, 0);
     P->inv = s_inverse;
     P->fwd = s_forward;
     return P;
