@@ -1,8 +1,11 @@
 #define PJ_LIB__
 #include <errno.h>
+#include <math.h>
+#include <stddef.h>
+#include <string.h>
+
 #include "proj.h"
 #include "projects.h"
-#include <string.h>
 
 struct pj_opaque {
     struct PJconsts *link;
@@ -48,11 +51,11 @@ static XY t_forward(LP lp, PJ *P) {             /* spheroid */
 
 
 static LP o_inverse(XY xy, PJ *P) {             /* spheroid */
-    LP lp = {0.0,0.0};
+
     struct pj_opaque *Q = P->opaque;
     double coslam, sinphi, cosphi;
 
-    lp = Q->link->inv(xy, Q->link);
+    LP lp = Q->link->inv(xy, Q->link);
     if (lp.lam != HUGE_VAL) {
         coslam = cos(lp.lam -= Q->lamp);
         sinphi = sin(lp.phi);
@@ -66,11 +69,11 @@ static LP o_inverse(XY xy, PJ *P) {             /* spheroid */
 
 
 static LP t_inverse(XY xy, PJ *P) {             /* spheroid */
-    LP lp = {0.0,0.0};
+
     struct pj_opaque *Q = P->opaque;
     double cosphi, t;
 
-    lp = Q->link->inv(xy, Q->link);
+    LP lp = Q->link->inv(xy, Q->link);
     if (lp.lam != HUGE_VAL) {
         cosphi = cos(lp.phi);
         t = lp.lam - Q->lamp;
@@ -238,4 +241,3 @@ PJ *PROJECTION(ob_tran) {
 
     return P;
 }
-
