@@ -101,6 +101,7 @@ static const char usage[] = {
     "--------------------------------------------------------------------------------\n"
     "    -c x,y,z,t        Specify input columns for (up to) 4 input parameters.\n"
     "                      Defaults to 1,2,3,4\n"
+    "    -d n              Specify number of decimals in output.\n"
     "    -I                Do the inverse transformation\n"
     "    -o /path/to/file  Specify output file name\n"
     "    -t value          Provide a fixed t value for all input data (e.g. -t 0)\n"
@@ -113,6 +114,7 @@ static const char usage[] = {
     "--------------------------------------------------------------------------------\n"
     "    --output          Alias for -o\n"
     "    --columns         Alias for -c\n"
+    "    --decimals        Alias for -d\n"
     "    --height          Alias for -z\n"
     "    --time            Alias for -t\n"
     "    --verbose         Alias for -v\n"
@@ -185,8 +187,10 @@ static void print(PJ_LOG_LEVEL log_level, const char *fmt, ...) {
     va_start( args, fmt );
 
     msg_buf = (char *) malloc(100000);
-    if( msg_buf == NULL )
+    if( msg_buf == NULL ) {
+        va_end( args );
         return;
+    }
 
     vsprintf( msg_buf, fmt, args );
 
@@ -202,14 +206,21 @@ int main(int argc, char **argv) {
     PJ_COORD point;
     PJ_PROJ_INFO info;
     OPTARGS *o;
+    char blank_comment[] = "";
+    char whitespace[] = " ";
+    char *comment;
+    char *comment_delimiter;
     char *buf;
-    int nfields = 4, direction = 1, skip_lines = 0, verbose;
+    int i, nfields = 4, direction = 1, skip_lines = 0, verbose;
     double fixed_z = HUGE_VAL, fixed_time = HUGE_VAL;
+    int decimals_angles = 10;
+    int decimals_distances = 4;
     int columns_xyzt[] = {1, 2, 3, 4};
     const char *longflags[]  = {"v=verbose", "h=help", "I=inverse", "version", 0};
     const char *longkeys[]   = {
         "o=output",
         "c=columns",
+        "d=decimals",
         "z=height",
         "t=time",
         "s=skip-lines",
@@ -217,7 +228,7 @@ int main(int argc, char **argv) {
 
     fout = stdout;
 
-    o = opt_parse (argc, argv, "hvI", "cozts", longflags, longkeys);
+    o = opt_parse (argc, argv, "hvI", "cdozts", longflags, longkeys);
     if (0==o)
         return 0;
 
@@ -257,13 +268,24 @@ int main(int argc, char **argv) {
         nfields--;
     }
 
+     if (opt_given (o, "d")) {
+        int dec = atoi (opt_arg (o, "d"));
+        decimals_angles = dec;
+        decimals_distances = dec;
+    }
+
     if (opt_given (o, "s")) {
         skip_lines = atoi (opt_arg(o, "s"));
     }
 
     if (opt_given (o, "c")) {
+        int ncols;
+        /* reset colum numbers to ease comment output later on */
+        for (i=0; i<4; i++)
+            columns_xyzt[i] = 0;
+
         /* cppcheck-suppress invalidscanf */
-        int ncols = sscanf (opt_arg (o, "c"), "%d,%d,%d,%d", columns_xyzt, columns_xyzt+1, columns_xyzt+2, columns_xyzt+3);
+        ncols = sscanf (opt_arg (o, "c"), "%d,%d,%d,%d", columns_xyzt, columns_xyzt+1, columns_xyzt+2, columns_xyzt+3);
         if (ncols != nfields) {
             print (PJ_LOG_ERROR, "%s: Too few input columns given: '%s'\n", o->progname, opt_arg (o, "c"));
             free (o);
@@ -357,14 +379,35 @@ int main(int argc, char **argv) {
         }
         proj_errno_restore (P, err);
 
+        /* handle comment string */
+        comment = column(buf, nfields+1);
+        if (opt_given(o, "c")) {
+            /* what number is the last coordinate column in the input data? */
+            int colmax = 0;
+            for (i=0; i<4; i++)
+                colmax = MAX(colmax, columns_xyzt[i]);
+            comment = column(buf, colmax+1);
+        }
+        comment_delimiter = (comment && *comment) ? whitespace : blank_comment;
+
         /* Time to print the result */
         if (proj_angular_output (P, direction)) {
             point.lpzt.lam = proj_todeg (point.lpzt.lam);
             point.lpzt.phi = proj_todeg (point.lpzt.phi);
-            print (PJ_LOG_NONE, "%14.10f  %14.10f  %12.4f  %12.4f\n", point.xyzt.x, point.xyzt.y, point.xyzt.z, point.xyzt.t);
+            print (PJ_LOG_NONE, "%14.*f  %14.*f  %12.*f  %12.4f%s%s\n",
+                   decimals_angles, point.xyzt.x,
+                   decimals_angles, point.xyzt.y,
+                   decimals_distances, point.xyzt.z,
+                   point.xyzt.t, comment_delimiter, comment
+            );
         }
         else
-            print (PJ_LOG_NONE, "%13.4f  %13.4f  %12.4f  %12.4f\n", point.xyzt.x, point.xyzt.y, point.xyzt.z, point.xyzt.t);
+            print (PJ_LOG_NONE, "%13.*f  %13.*f  %12.*f  %12.4f%s%s\n",
+                   decimals_distances, point.xyzt.x,
+                   decimals_distances, point.xyzt.y,
+                   decimals_distances, point.xyzt.z,
+                   point.xyzt.t, comment_delimiter, comment
+            );
     }
 
     if (stdout != fout)
