@@ -26,15 +26,16 @@
  * DEALINGS IN THE SOFTWARE.
  *****************************************************************************/
 
-#include "proj.h"
-#include "projects.h"
+#include <ctype.h>
+#include <locale.h>
+#include <math.h>
 #include <stdio.h>
 #include <stdlib.h>
-#include <ctype.h>
 #include <string.h>
-#include <math.h>
+
+#include "proj.h"
+#include "projects.h"
 #include "emess.h"
-#include <locale.h>
 
 #define MAX_LINE 1000
 #define MAX_PARGS 100
@@ -48,9 +49,10 @@ echoin = 0,	/* echo input data to output line */
 tag = '#';	/* beginning of line tag character */
 	static char
 *oform = (char *)0,	/* output format for x-y or decimal degrees */
+ oform_buffer[16],	/* buffer for oform when using -d */
 *oterr = "*\t*",	/* output line for unprojectable input */
 *usage =
-"%s\nusage: %s [ -eEfIlrstvwW [args] ] [ +opts[=arg] ]\n"
+"%s\nusage: %s [ -dDeEfIlrstvwW [args] ] [ +opts[=arg] ]\n"
 "                   [+to [+opts[=arg] [ files ]\n";
 
 static double (*informat)(const char *, 
@@ -133,8 +135,8 @@ static void process(FILE *fid)
                 fputs(rtodms(pline, data.v, 'N', 'S'), stdout);
             }
 
-        } else {	/* x-y or decimal degree ascii output */
-            if ( pj_is_latlong(toProj) ) {
+        } else { /* x-y or decimal degree ascii output */
+            if ( proj_angular_output(toProj, PJ_FWD) ) {
                 data.v *= RAD_TO_DEG;
                 data.u *= RAD_TO_DEG;
             }
@@ -263,6 +265,7 @@ int main(int argc, char **argv)
                 } else
                     emess(1,"invalid list option: l%c",arg[1]);
                 exit(0);
+                /* cppcheck-suppress duplicateBreak */
                 continue; /* artificial */
               case 'e': /* error line alternative */
                 if (--argc <= 0)
@@ -291,10 +294,15 @@ int main(int argc, char **argv)
               case 's': /* reverse output */
                 reverseout = 1;
                 continue;
-              case 'd': /* set debug level */
+              case 'D': /* set debug level */
                 if (--argc <= 0) goto noargument;
                 pj_ctx_set_debug( pj_get_default_ctx(), atoi(*++argv));
                 continue;
+              case 'd':
+                if (--argc <= 0) goto noargument;
+                sprintf(oform_buffer, "%%.%df", atoi(*++argv));
+                oform = oform_buffer;
+                break;
               default:
                 emess(1, "invalid option: -%c",*arg);
                 break;
@@ -446,10 +454,8 @@ int main(int argc, char **argv)
         emess_dat.File_name = 0;
     }
 
-    if( fromProj != NULL )
-        pj_free( fromProj );
-    if( toProj != NULL )
-        pj_free( toProj );
+    pj_free( fromProj );
+    pj_free( toProj );
 
     pj_deallocate_grids();
 
