@@ -22,10 +22,17 @@
 
 static const double wgs84_a = 6378137, wgs84_f = 1/298.257223563; /* WGS84 */
 
-static int assertEquals(double x, double y, double d) {
+static int checkEquals(double x, double y, double d) {
   if (fabs(x - y) <= d)
     return 0;
-  printf("assertEquals fails: %.7g != %.7g +/- %.7g\n", x, y, d);
+  printf("checkEquals fails: %.7g != %.7g +/- %.7g\n", x, y, d);
+  return 1;
+}
+
+static int checkNaN(double x) {
+  if (x != x)
+    return 0;
+  printf("checkNaN fails: %.7g\n", x);
   return 1;
 }
 
@@ -125,14 +132,14 @@ static int testinverse() {
     M12 = testcases[i][9]; M21 = testcases[i][10]; S12 = testcases[i][11];
     a12a = geod_geninverse(&g, lat1, lon1, lat2, lon2, &s12a, &azi1a, &azi2a,
                &m12a, &M12a, &M21a, &S12a);
-    result += assertEquals(azi1, azi1a, 1e-13);
-    result += assertEquals(azi2, azi2a, 1e-13);
-    result += assertEquals(s12, s12a, 1e-8);
-    result += assertEquals(a12, a12a, 1e-13);
-    result += assertEquals(m12, m12a, 1e-8);
-    result += assertEquals(M12, M12a, 1e-15);
-    result += assertEquals(M21, M21a, 1e-15);
-    result += assertEquals(S12, S12a, 0.1);
+    result += checkEquals(azi1, azi1a, 1e-13);
+    result += checkEquals(azi2, azi2a, 1e-13);
+    result += checkEquals(s12, s12a, 1e-8);
+    result += checkEquals(a12, a12a, 1e-13);
+    result += checkEquals(m12, m12a, 1e-8);
+    result += checkEquals(M12, M12a, 1e-15);
+    result += checkEquals(M21, M21a, 1e-15);
+    result += checkEquals(S12, S12a, 0.1);
   }
   return result;
 }
@@ -152,14 +159,14 @@ static int testdirect() {
     a12a = geod_gendirect(&g, lat1, lon1, azi1, flags, s12,
               &lat2a, &lon2a, &azi2a, 0,
               &m12a, &M12a, &M21a, &S12a);
-    result += assertEquals(lat2, lat2a, 1e-13);
-    result += assertEquals(lon2, lon2a, 1e-13);
-    result += assertEquals(azi2, azi2a, 1e-13);
-    result += assertEquals(a12, a12a, 1e-13);
-    result += assertEquals(m12, m12a, 1e-8);
-    result += assertEquals(M12, M12a, 1e-15);
-    result += assertEquals(M21, M21a, 1e-15);
-    result += assertEquals(S12, S12a, 0.1);
+    result += checkEquals(lat2, lat2a, 1e-13);
+    result += checkEquals(lon2, lon2a, 1e-13);
+    result += checkEquals(azi2, azi2a, 1e-13);
+    result += checkEquals(a12, a12a, 1e-13);
+    result += checkEquals(m12, m12a, 1e-8);
+    result += checkEquals(M12, M12a, 1e-15);
+    result += checkEquals(M21, M21a, 1e-15);
+    result += checkEquals(S12, S12a, 0.1);
   }
   return result;
 }
@@ -178,14 +185,14 @@ static int testarcdirect() {
     M12 = testcases[i][9]; M21 = testcases[i][10]; S12 = testcases[i][11];
     geod_gendirect(&g, lat1, lon1, azi1, flags, a12,
                    &lat2a, &lon2a, &azi2a, &s12a, &m12a, &M12a, &M21a, &S12a);
-    result += assertEquals(lat2, lat2a, 1e-13);
-    result += assertEquals(lon2, lon2a, 1e-13);
-    result += assertEquals(azi2, azi2a, 1e-13);
-    result += assertEquals(s12, s12a, 1e-8);
-    result += assertEquals(m12, m12a, 1e-8);
-    result += assertEquals(M12, M12a, 1e-15);
-    result += assertEquals(M21, M21a, 1e-15);
-    result += assertEquals(S12, S12a, 0.1);
+    result += checkEquals(lat2, lat2a, 1e-13);
+    result += checkEquals(lon2, lon2a, 1e-13);
+    result += checkEquals(azi2, azi2a, 1e-13);
+    result += checkEquals(s12, s12a, 1e-8);
+    result += checkEquals(m12, m12a, 1e-8);
+    result += checkEquals(M12, M12a, 1e-15);
+    result += checkEquals(M21, M21a, 1e-15);
+    result += checkEquals(S12, S12a, 0.1);
   }
   return result;
 }
@@ -196,9 +203,9 @@ static int GeodSolve0() {
   int result = 0;
   geod_init(&g, wgs84_a, wgs84_f);
   geod_inverse(&g, 40.6, -73.8, 49.01666667, 2.55, &s12, &azi1, &azi2);
-  result += assertEquals(azi1, 53.47022, 0.5e-5);
-  result += assertEquals(azi2, 111.59367, 0.5e-5);
-  result += assertEquals(s12, 5853226, 0.5);
+  result += checkEquals(azi1, 53.47022, 0.5e-5);
+  result += checkEquals(azi2, 111.59367, 0.5e-5);
+  result += checkEquals(s12, 5853226, 0.5);
   return result;
 }
 
@@ -209,9 +216,9 @@ static int GeodSolve1() {
   geod_init(&g, wgs84_a, wgs84_f);
   geod_direct(&g, 40.63972222, -73.77888889, 53.5, 5850e3,
               &lat2, &lon2, &azi2);
-  result += assertEquals(lat2, 49.01467, 0.5e-5);
-  result += assertEquals(lon2, 2.56106, 0.5e-5);
-  result += assertEquals(azi2, 111.62947, 0.5e-5);
+  result += checkEquals(lat2, 49.01467, 0.5e-5);
+  result += checkEquals(lon2, 2.56106, 0.5e-5);
+  result += checkEquals(azi2, 111.62947, 0.5e-5);
   return result;
 }
 
@@ -222,13 +229,13 @@ static int GeodSolve2() {
   int result = 0;
   geod_init(&g, 6.4e6, -1/150.0);
   geod_inverse(&g, 0.07476, 0, -0.07476, 180, &s12, &azi1, &azi2);
-  result += assertEquals(azi1, 90.00078, 0.5e-5);
-  result += assertEquals(azi2, 90.00078, 0.5e-5);
-  result += assertEquals(s12, 20106193, 0.5);
+  result += checkEquals(azi1, 90.00078, 0.5e-5);
+  result += checkEquals(azi2, 90.00078, 0.5e-5);
+  result += checkEquals(s12, 20106193, 0.5);
   geod_inverse(&g, 0.1, 0, -0.1, 180, &s12, &azi1, &azi2);
-  result += assertEquals(azi1, 90.00105, 0.5e-5);
-  result += assertEquals(azi2, 90.00105, 0.5e-5);
-  result += assertEquals(s12, 20106193, 0.5);
+  result += checkEquals(azi1, 90.00105, 0.5e-5);
+  result += checkEquals(azi2, 90.00105, 0.5e-5);
+  result += checkEquals(s12, 20106193, 0.5);
   return result;
 }
 
@@ -240,7 +247,7 @@ static int GeodSolve4() {
   geod_init(&g, wgs84_a, wgs84_f);
   geod_inverse(&g, 36.493349428792, 0, 36.49334942879201, .0000008,
                &s12, 0, 0);
-  result += assertEquals(s12, 0.072, 0.5e-3);
+  result += checkEquals(s12, 0.072, 0.5e-3);
   return result;
 }
 
@@ -251,13 +258,13 @@ static int GeodSolve5() {
   int result = 0;
   geod_init(&g, wgs84_a, wgs84_f);
   geod_direct(&g, 0.01777745589997, 30, 0, 10e6, &lat2, &lon2, &azi2);
-  result += assertEquals(lat2, 90, 0.5e-5);
+  result += checkEquals(lat2, 90, 0.5e-5);
   if (lon2 < 0) {
-    result += assertEquals(lon2, -150, 0.5e-5);
-    result += assertEquals(fabs(azi2), 180, 0.5e-5);
+    result += checkEquals(lon2, -150, 0.5e-5);
+    result += checkEquals(fabs(azi2), 180, 0.5e-5);
   } else {
-    result += assertEquals(lon2, 30, 0.5e-5);
-    result += assertEquals(azi2, 0, 0.5e-5);
+    result += checkEquals(lon2, 30, 0.5e-5);
+    result += checkEquals(azi2, 0, 0.5e-5);
   }
   return result;
 }
@@ -271,13 +278,13 @@ static int GeodSolve6() {
   geod_init(&g, wgs84_a, wgs84_f);
   geod_inverse(&g, 88.202499451857, 0,
                -88.202499451857, 179.981022032992859592, &s12, 0, 0);
-  result += assertEquals(s12, 20003898.214, 0.5e-3);
+  result += checkEquals(s12, 20003898.214, 0.5e-3);
   geod_inverse(&g, 89.262080389218, 0,
                -89.262080389218, 179.992207982775375662, &s12, 0, 0);
-  result += assertEquals(s12, 20003925.854, 0.5e-3);
+  result += checkEquals(s12, 20003925.854, 0.5e-3);
   geod_inverse(&g, 89.333123580033, 0,
                -89.333123580032997687, 179.99295812360148422, &s12, 0, 0);
-  result += assertEquals(s12, 20003926.881, 0.5e-3);
+  result += checkEquals(s12, 20003926.881, 0.5e-3);
   return result;
 }
 
@@ -289,7 +296,7 @@ static int GeodSolve9() {
   geod_init(&g, wgs84_a, wgs84_f);
   geod_inverse(&g, 56.320923501171, 0,
                -56.320923501171, 179.664747671772880215, &s12, 0, 0);
-  result += assertEquals(s12, 19993558.287, 0.5e-3);
+  result += checkEquals(s12, 19993558.287, 0.5e-3);
   return result;
 }
 
@@ -302,7 +309,7 @@ static int GeodSolve10() {
   geod_init(&g, wgs84_a, wgs84_f);
   geod_inverse(&g, 52.784459512564, 0,
                -52.784459512563990912, 179.634407464943777557, &s12, 0, 0);
-  result += assertEquals(s12, 19991596.095, 0.5e-3);
+  result += checkEquals(s12, 19991596.095, 0.5e-3);
   return result;
 }
 
@@ -315,7 +322,7 @@ static int GeodSolve11() {
   geod_init(&g, wgs84_a, wgs84_f);
   geod_inverse(&g, 48.522876735459, 0,
                -48.52287673545898293, 179.599720456223079643, &s12, 0, 0);
-  result += assertEquals(s12, 19989144.774, 0.5e-3);
+  result += checkEquals(s12, 19989144.774, 0.5e-3);
   return result;
 }
 
@@ -328,9 +335,9 @@ static int GeodSolve12() {
   int result = 0;
   geod_init(&g, 89.8, -1.83);
   geod_inverse(&g, 0, 0, -10, 160, &s12, &azi1, &azi2);
-  result += assertEquals(azi1, 120.27, 1e-2);
-  result += assertEquals(azi2, 105.15, 1e-2);
-  result += assertEquals(s12, 266.7, 1e-1);
+  result += checkEquals(azi1, 120.27, 1e-2);
+  result += checkEquals(azi2, 105.15, 1e-2);
+  result += checkEquals(s12, 266.7, 1e-1);
   return result;
 }
 
@@ -341,13 +348,14 @@ static int GeodSolve14() {
   int result = 0;
   {
     double minus1 = -1;
+    /* cppcheck-suppress wrongmathcall */
     nan = sqrt(minus1);
   }
   geod_init(&g, wgs84_a, wgs84_f);
   geod_inverse(&g, 0, 0, 1, nan, &s12, &azi1, &azi2);
-  result += azi1 == azi1 ? 1 : 0;
-  result += azi2 == azi2 ? 1 : 0;
-  result += s12 == s12 ? 1 : 0;
+  result += checkNaN(azi1);
+  result += checkNaN(azi2);
+  result += checkNaN(s12);
   return result;
 }
 
@@ -360,7 +368,7 @@ static int GeodSolve15() {
   geod_init(&g, 6.4e6, -1/150.0);
   geod_gendirect(&g, 1, 2, 3, 0, 4,
                  0, 0, 0, 0, 0, 0, 0, &S12);
-  result += assertEquals(S12, 23700, 0.5);
+  result += checkEquals(S12, 23700, 0.5);
   return result;
 }
 
@@ -374,22 +382,22 @@ static int GeodSolve17() {
   geod_init(&g, wgs84_a, wgs84_f);
   geod_gendirect(&g, 40, -75, -10, flags, 2e7,
                  &lat2, &lon2, &azi2, 0, 0, 0, 0, 0);
-  result += assertEquals(lat2, -39, 1);
-  result += assertEquals(lon2, -254, 1);
-  result += assertEquals(azi2, -170, 1);
+  result += checkEquals(lat2, -39, 1);
+  result += checkEquals(lon2, -254, 1);
+  result += checkEquals(azi2, -170, 1);
   geod_lineinit(&l, &g, 40, -75, -10, 0);
   geod_genposition(&l, flags, 2e7, &lat2, &lon2, &azi2, 0, 0, 0, 0, 0);
-  result += assertEquals(lat2, -39, 1);
-  result += assertEquals(lon2, -254, 1);
-  result += assertEquals(azi2, -170, 1);
+  result += checkEquals(lat2, -39, 1);
+  result += checkEquals(lon2, -254, 1);
+  result += checkEquals(azi2, -170, 1);
   geod_direct(&g, 40, -75, -10, 2e7, &lat2, &lon2, &azi2);
-  result += assertEquals(lat2, -39, 1);
-  result += assertEquals(lon2, 105, 1);
-  result += assertEquals(azi2, -170, 1);
+  result += checkEquals(lat2, -39, 1);
+  result += checkEquals(lon2, 105, 1);
+  result += checkEquals(azi2, -170, 1);
   geod_position(&l, 2e7, &lat2, &lon2, &azi2);
-  result += assertEquals(lat2, -39, 1);
-  result += assertEquals(lon2, 105, 1);
-  result += assertEquals(azi2, -170, 1);
+  result += checkEquals(lat2, -39, 1);
+  result += checkEquals(lon2, 105, 1);
+  result += checkEquals(azi2, -170, 1);
   return result;
 }
 
@@ -400,7 +408,7 @@ static int GeodSolve26() {
   int result = 0;
   geod_init(&g, 6.4e6, 0);
   geod_geninverse(&g, 1, 2, 3, 4, 0, 0, 0, 0, 0, 0, &S12);
-  result += assertEquals(S12, 49911046115.0, 0.5);
+  result += checkEquals(S12, 49911046115.0, 0.5);
   return result;
 }
 
@@ -412,7 +420,7 @@ static int GeodSolve28() {
   int result = 0;
   geod_init(&g, 6.4e6, 0.1);
   a12 = geod_gendirect(&g, 1, 2, 10, 0, 5e6, 0, 0, 0, 0, 0, 0, 0, 0);
-  result += assertEquals(a12, 48.55570690, 0.5e-8);
+  result += checkEquals(a12, 48.55570690, 0.5e-8);
   return result;
 }
 
@@ -425,51 +433,51 @@ static int GeodSolve33() {
   int result = 0;
   geod_init(&g, wgs84_a, wgs84_f);
   geod_inverse(&g, 0, 0, 0, 179, &s12, &azi1, &azi2);
-  result += assertEquals(azi1, 90.00000, 0.5e-5);
-  result += assertEquals(azi2, 90.00000, 0.5e-5);
-  result += assertEquals(s12, 19926189, 0.5);
+  result += checkEquals(azi1, 90.00000, 0.5e-5);
+  result += checkEquals(azi2, 90.00000, 0.5e-5);
+  result += checkEquals(s12, 19926189, 0.5);
   geod_inverse(&g, 0, 0, 0, 179.5, &s12, &azi1, &azi2);
-  result += assertEquals(azi1, 55.96650, 0.5e-5);
-  result += assertEquals(azi2, 124.03350, 0.5e-5);
-  result += assertEquals(s12, 19980862, 0.5);
+  result += checkEquals(azi1, 55.96650, 0.5e-5);
+  result += checkEquals(azi2, 124.03350, 0.5e-5);
+  result += checkEquals(s12, 19980862, 0.5);
   geod_inverse(&g, 0, 0, 0, 180, &s12, &azi1, &azi2);
-  result += assertEquals(azi1, 0.00000, 0.5e-5);
-  result += assertEquals(fabs(azi2), 180.00000, 0.5e-5);
-  result += assertEquals(s12, 20003931, 0.5);
+  result += checkEquals(azi1, 0.00000, 0.5e-5);
+  result += checkEquals(fabs(azi2), 180.00000, 0.5e-5);
+  result += checkEquals(s12, 20003931, 0.5);
   geod_inverse(&g, 0, 0, 1, 180, &s12, &azi1, &azi2);
-  result += assertEquals(azi1, 0.00000, 0.5e-5);
-  result += assertEquals(fabs(azi2), 180.00000, 0.5e-5);
-  result += assertEquals(s12, 19893357, 0.5);
+  result += checkEquals(azi1, 0.00000, 0.5e-5);
+  result += checkEquals(fabs(azi2), 180.00000, 0.5e-5);
+  result += checkEquals(s12, 19893357, 0.5);
   geod_init(&g, 6.4e6, 0);
   geod_inverse(&g, 0, 0, 0, 179, &s12, &azi1, &azi2);
-  result += assertEquals(azi1, 90.00000, 0.5e-5);
-  result += assertEquals(azi2, 90.00000, 0.5e-5);
-  result += assertEquals(s12, 19994492, 0.5);
+  result += checkEquals(azi1, 90.00000, 0.5e-5);
+  result += checkEquals(azi2, 90.00000, 0.5e-5);
+  result += checkEquals(s12, 19994492, 0.5);
   geod_inverse(&g, 0, 0, 0, 180, &s12, &azi1, &azi2);
-  result += assertEquals(azi1, 0.00000, 0.5e-5);
-  result += assertEquals(fabs(azi2), 180.00000, 0.5e-5);
-  result += assertEquals(s12, 20106193, 0.5);
+  result += checkEquals(azi1, 0.00000, 0.5e-5);
+  result += checkEquals(fabs(azi2), 180.00000, 0.5e-5);
+  result += checkEquals(s12, 20106193, 0.5);
   geod_inverse(&g, 0, 0, 1, 180, &s12, &azi1, &azi2);
-  result += assertEquals(azi1, 0.00000, 0.5e-5);
-  result += assertEquals(fabs(azi2), 180.00000, 0.5e-5);
-  result += assertEquals(s12, 19994492, 0.5);
+  result += checkEquals(azi1, 0.00000, 0.5e-5);
+  result += checkEquals(fabs(azi2), 180.00000, 0.5e-5);
+  result += checkEquals(s12, 19994492, 0.5);
   geod_init(&g, 6.4e6, -1/300.0);
   geod_inverse(&g, 0, 0, 0, 179, &s12, &azi1, &azi2);
-  result += assertEquals(azi1, 90.00000, 0.5e-5);
-  result += assertEquals(azi2, 90.00000, 0.5e-5);
-  result += assertEquals(s12, 19994492, 0.5);
+  result += checkEquals(azi1, 90.00000, 0.5e-5);
+  result += checkEquals(azi2, 90.00000, 0.5e-5);
+  result += checkEquals(s12, 19994492, 0.5);
   geod_inverse(&g, 0, 0, 0, 180, &s12, &azi1, &azi2);
-  result += assertEquals(azi1, 90.00000, 0.5e-5);
-  result += assertEquals(azi2, 90.00000, 0.5e-5);
-  result += assertEquals(s12, 20106193, 0.5);
+  result += checkEquals(azi1, 90.00000, 0.5e-5);
+  result += checkEquals(azi2, 90.00000, 0.5e-5);
+  result += checkEquals(s12, 20106193, 0.5);
   geod_inverse(&g, 0, 0, 0.5, 180, &s12, &azi1, &azi2);
-  result += assertEquals(azi1, 33.02493, 0.5e-5);
-  result += assertEquals(azi2, 146.97364, 0.5e-5);
-  result += assertEquals(s12, 20082617, 0.5);
+  result += checkEquals(azi1, 33.02493, 0.5e-5);
+  result += checkEquals(azi2, 146.97364, 0.5e-5);
+  result += checkEquals(s12, 20082617, 0.5);
   geod_inverse(&g, 0, 0, 1, 180, &s12, &azi1, &azi2);
-  result += assertEquals(azi1, 0.00000, 0.5e-5);
-  result += assertEquals(fabs(azi2), 180.00000, 0.5e-5);
-  result += assertEquals(s12, 20027270, 0.5);
+  result += checkEquals(azi1, 0.00000, 0.5e-5);
+  result += checkEquals(fabs(azi2), 180.00000, 0.5e-5);
+  result += checkEquals(s12, 20027270, 0.5);
 
   return result;
 }
@@ -482,17 +490,18 @@ static int GeodSolve55() {
   int result = 0;
   {
     double minus1 = -1;
+    /* cppcheck-suppress wrongmathcall */
     nan = sqrt(minus1);
   }
   geod_init(&g, wgs84_a, wgs84_f);
   geod_inverse(&g, nan, 0, 0, 90, &s12, &azi1, &azi2);
-  result += azi1 == azi1 ? 1 : 0;
-  result += azi2 == azi2 ? 1 : 0;
-  result += s12 == s12 ? 1 : 0;
+  result += checkNaN(azi1);
+  result += checkNaN(azi2);
+  result += checkNaN(s12);
   geod_inverse(&g, nan, 0, 90, 9, &s12, &azi1, &azi2);
-  result += azi1 == azi1 ? 1 : 0;
-  result += azi2 == azi2 ? 1 : 0;
-  result += s12 == s12 ? 1 : 0;
+  result += checkNaN(azi1);
+  result += checkNaN(azi2);
+  result += checkNaN(s12);
   return result;
 }
 
@@ -503,9 +512,9 @@ static int GeodSolve59() {
   int result = 0;
   geod_init(&g, wgs84_a, wgs84_f);
   geod_inverse(&g, 5, 0.00000000000001, 10, 180, &s12, &azi1, &azi2);
-  result += assertEquals(azi1, 0.000000000000035, 1.5e-14);
-  result += assertEquals(azi2, 179.99999999999996, 1.5e-14);
-  result += assertEquals(s12, 18345191.174332713, 5e-9);
+  result += checkEquals(azi1, 0.000000000000035, 1.5e-14);
+  result += checkEquals(azi2, 179.99999999999996, 1.5e-14);
+  result += checkEquals(s12, 18345191.174332713, 5e-9);
   return result;
 }
 
@@ -519,14 +528,14 @@ static int GeodSolve61() {
   geod_init(&g, wgs84_a, wgs84_f);
   geod_gendirect(&g, 45, 0, -0.000000000000000003, flags, 1e7,
                  &lat2, &lon2, &azi2, 0, 0, 0, 0, 0);
-  result += assertEquals(lat2, 45.30632, 0.5e-5);
-  result += assertEquals(lon2, -180, 0.5e-5);
-  result += assertEquals(fabs(azi2), 180, 0.5e-5);
+  result += checkEquals(lat2, 45.30632, 0.5e-5);
+  result += checkEquals(lon2, -180, 0.5e-5);
+  result += checkEquals(fabs(azi2), 180, 0.5e-5);
   geod_inverseline(&l, &g, 45, 0, 80, -0.000000000000000003, 0);
   geod_genposition(&l, flags, 1e7, &lat2, &lon2, &azi2, 0, 0, 0, 0, 0);
-  result += assertEquals(lat2, 45.30632, 0.5e-5);
-  result += assertEquals(lon2, -180, 0.5e-5);
-  result += assertEquals(fabs(azi2), 180, 0.5e-5);
+  result += checkEquals(lat2, 45.30632, 0.5e-5);
+  result += checkEquals(lon2, -180, 0.5e-5);
+  result += checkEquals(fabs(azi2), 180, 0.5e-5);
   return result;
 }
 
@@ -543,26 +552,26 @@ static int GeodSolve65() {
   geod_inverseline(&l, &g, 30, -0.000000000000000001, -31, 180, caps);
   a12 = geod_genposition(&l, flags, 1e7,
                          &lat2, &lon2, &azi2, &s12, &m12, &M12, &M21, &S12);
-  result += assertEquals(lat2, -60.23169, 0.5e-5);
-  result += assertEquals(lon2, -0.00000, 0.5e-5);
-  result += assertEquals(fabs(azi2), 180.00000, 0.5e-5);
-  result += assertEquals(s12, 10000000, 0.5);
-  result += assertEquals(a12, 90.06544, 0.5e-5);
-  result += assertEquals(m12, 6363636, 0.5);
-  result += assertEquals(M12, -0.0012834, 0.5e-7);
-  result += assertEquals(M21, 0.0013749, 0.5e-7);
-  result += assertEquals(S12, 0, 0.5);
+  result += checkEquals(lat2, -60.23169, 0.5e-5);
+  result += checkEquals(lon2, -0.00000, 0.5e-5);
+  result += checkEquals(fabs(azi2), 180.00000, 0.5e-5);
+  result += checkEquals(s12, 10000000, 0.5);
+  result += checkEquals(a12, 90.06544, 0.5e-5);
+  result += checkEquals(m12, 6363636, 0.5);
+  result += checkEquals(M12, -0.0012834, 0.5e-7);
+  result += checkEquals(M21, 0.0013749, 0.5e-7);
+  result += checkEquals(S12, 0, 0.5);
   a12 = geod_genposition(&l, flags, 2e7,
                          &lat2, &lon2, &azi2, &s12, &m12, &M12, &M21, &S12);
-  result += assertEquals(lat2, -30.03547, 0.5e-5);
-  result += assertEquals(lon2, -180.00000, 0.5e-5);
-  result += assertEquals(azi2, -0.00000, 0.5e-5);
-  result += assertEquals(s12, 20000000, 0.5);
-  result += assertEquals(a12, 179.96459, 0.5e-5);
-  result += assertEquals(m12, 54342, 0.5);
-  result += assertEquals(M12, -1.0045592, 0.5e-7);
-  result += assertEquals(M21, -0.9954339, 0.5e-7);
-  result += assertEquals(S12, 127516405431022.0, 0.5);
+  result += checkEquals(lat2, -30.03547, 0.5e-5);
+  result += checkEquals(lon2, -180.00000, 0.5e-5);
+  result += checkEquals(azi2, -0.00000, 0.5e-5);
+  result += checkEquals(s12, 20000000, 0.5);
+  result += checkEquals(a12, 179.96459, 0.5e-5);
+  result += checkEquals(m12, 54342, 0.5);
+  result += checkEquals(M12, -1.0045592, 0.5e-7);
+  result += checkEquals(M21, -0.9954339, 0.5e-7);
+  result += checkEquals(S12, 127516405431022.0, 0.5);
   return result;
 }
 
@@ -577,13 +586,13 @@ static int GeodSolve67() {
   geod_init(&g, wgs84_a, wgs84_f);
   geod_inverseline(&l, &g, -5, -0.000000000000002, -10, 180, 0);
   geod_genposition(&l, flags, 2e7, &lat2, &lon2, &azi2, 0, 0, 0, 0, 0);
-  result += assertEquals(lat2, 4.96445, 0.5e-5);
-  result += assertEquals(lon2, -180.00000, 0.5e-5);
-  result += assertEquals(azi2, -0.00000, 0.5e-5);
+  result += checkEquals(lat2, 4.96445, 0.5e-5);
+  result += checkEquals(lon2, -180.00000, 0.5e-5);
+  result += checkEquals(azi2, -0.00000, 0.5e-5);
   geod_genposition(&l, flags, 0.5 * l.s13, &lat2, &lon2, &azi2, 0, 0, 0, 0, 0);
-  result += assertEquals(lat2, -87.52461, 0.5e-5);
-  result += assertEquals(lon2, -0.00000, 0.5e-5);
-  result += assertEquals(azi2, -180.00000, 0.5e-5);
+  result += checkEquals(lat2, -87.52461, 0.5e-5);
+  result += checkEquals(lon2, -0.00000, 0.5e-5);
+  result += checkEquals(azi2, -180.00000, 0.5e-5);
   return result;
 }
 
@@ -596,9 +605,9 @@ static int GeodSolve71() {
   geod_init(&g, wgs84_a, wgs84_f);
   geod_directline(&l, &g, 1, 2, 45, 1e7, 0);
   geod_position(&l, 0.5 * l.s13, &lat2, &lon2, &azi2);
-  result += assertEquals(lat2, 30.92625, 0.5e-5);
-  result += assertEquals(lon2, 37.54640, 0.5e-5);
-  result += assertEquals(azi2, 55.43104, 0.5e-5);
+  result += checkEquals(lat2, 30.92625, 0.5e-5);
+  result += checkEquals(lon2, 37.54640, 0.5e-5);
+  result += checkEquals(azi2, 55.43104, 0.5e-5);
   return result;
 }
 
@@ -612,9 +621,10 @@ static int GeodSolve73() {
   geod_init(&g, wgs84_a, wgs84_f);
   geod_direct(&g, 90, 10, 180, -1e6,
               &lat2, &lon2, &azi2);
-  result += assertEquals(lat2, 81.04623, 0.5e-5);
-  result += assertEquals(lon2, -170, 0.5e-5);
-  result += assertEquals(azi2, 0, 0.5e-5);
+  result += checkEquals(lat2, 81.04623, 0.5e-5);
+  result += checkEquals(lon2, -170, 0.5e-5);
+  result += azi2 == 0 ? 0 : 1;
+  result += 1/azi2 > 0 ? 0 : 1; /* Check that azi2 = +0.0 not -0.0 */
   return result;
 }
 
@@ -649,14 +659,14 @@ static int GeodSolve74() {
   geod_init(&g, wgs84_a, wgs84_f);
   a12 = geod_geninverse(&g, 54.1589, 15.3872, 54.1591, 15.3877,
                         &s12, &azi1, &azi2, &m12, &M12, &M21, &S12);
-  result += assertEquals(azi1, 55.723110355, 5e-9);
-  result += assertEquals(azi2, 55.723515675, 5e-9);
-  result += assertEquals(s12,  39.527686385, 5e-9);
-  result += assertEquals(a12,   0.000355495, 5e-9);
-  result += assertEquals(m12,  39.527686385, 5e-9);
-  result += assertEquals(M12,   0.999999995, 5e-9);
-  result += assertEquals(M21,   0.999999995, 5e-9);
-  result += assertEquals(S12, 286698586.30197, 5e-4);
+  result += checkEquals(azi1, 55.723110355, 5e-9);
+  result += checkEquals(azi2, 55.723515675, 5e-9);
+  result += checkEquals(s12,  39.527686385, 5e-9);
+  result += checkEquals(a12,   0.000355495, 5e-9);
+  result += checkEquals(m12,  39.527686385, 5e-9);
+  result += checkEquals(M12,   0.999999995, 5e-9);
+  result += checkEquals(M21,   0.999999995, 5e-9);
+  result += checkEquals(S12, 286698586.30197, 5e-4);
   return result;
 }
 
@@ -669,9 +679,9 @@ static int GeodSolve76() {
   geod_init(&g, wgs84_a, wgs84_f);
   geod_inverse(&g, -(41+19/60.0), 174+49/60.0, 40+58/60.0, -(5+30/60.0),
                &s12, &azi1, &azi2);
-  result += assertEquals(azi1, 160.39137649664, 0.5e-11);
-  result += assertEquals(azi2,  19.50042925176, 0.5e-11);
-  result += assertEquals(s12,  19960543.857179, 0.5e-6);
+  result += checkEquals(azi1, 160.39137649664, 0.5e-11);
+  result += checkEquals(azi2,  19.50042925176, 0.5e-11);
+  result += checkEquals(s12,  19960543.857179, 0.5e-6);
   return result;
 }
 
@@ -682,9 +692,9 @@ static int GeodSolve78() {
   int result = 0;
   geod_init(&g, wgs84_a, wgs84_f);
   geod_inverse(&g, 27.2, 0.0, -27.1, 179.5, &s12, &azi1, &azi2);
-  result += assertEquals(azi1,  45.82468716758, 0.5e-11);
-  result += assertEquals(azi2, 134.22776532670, 0.5e-11);
-  result += assertEquals(s12,  19974354.765767, 0.5e-6);
+  result += checkEquals(azi1,  45.82468716758, 0.5e-11);
+  result += checkEquals(azi2, 134.22776532670, 0.5e-11);
+  result += checkEquals(s12,  19974354.765767, 0.5e-6);
   return result;
 }
 
@@ -698,35 +708,35 @@ static int GeodSolve80() {
   int result = 0;
   geod_init(&g, wgs84_a, wgs84_f);
   geod_geninverse(&g, 0, 0, 0, 90, 0, 0, 0, 0, &M12, &M21, 0);
-  result += assertEquals(M12, -0.00528427534, 0.5e-10);
-  result += assertEquals(M21, -0.00528427534, 0.5e-10);
+  result += checkEquals(M12, -0.00528427534, 0.5e-10);
+  result += checkEquals(M21, -0.00528427534, 0.5e-10);
   geod_geninverse(&g, 0, 0, 1e-6, 1e-6, 0, 0, 0, 0, &M12, &M21, 0);
-  result += assertEquals(M12, 1, 0.5e-10);
-  result += assertEquals(M21, 1, 0.5e-10);
+  result += checkEquals(M12, 1, 0.5e-10);
+  result += checkEquals(M21, 1, 0.5e-10);
   a12 = geod_geninverse(&g, 20.001, 0, 20.001, 0,
                         &s12, &azi1, &azi2, &m12, &M12, &M21, &S12);
-  result += assertEquals(a12, 0, 1e-13);
-  result += assertEquals(s12, 0, 1e-8);
-  result += assertEquals(azi1, 180, 1e-13);
-  result += assertEquals(azi2, 180, 1e-13);
-  result += assertEquals(m12, 0,  1e-8);
-  result += assertEquals(M12, 1, 1e-15);
-  result += assertEquals(M21, 1, 1e-15);
-  result += assertEquals(S12, 0, 1e-10);
+  result += checkEquals(a12, 0, 1e-13);
+  result += checkEquals(s12, 0, 1e-8);
+  result += checkEquals(azi1, 180, 1e-13);
+  result += checkEquals(azi2, 180, 1e-13);
+  result += checkEquals(m12, 0,  1e-8);
+  result += checkEquals(M12, 1, 1e-15);
+  result += checkEquals(M21, 1, 1e-15);
+  result += checkEquals(S12, 0, 1e-10);
   a12 = geod_geninverse(&g, 90, 0, 90, 180,
                         &s12, &azi1, &azi2, &m12, &M12, &M21, &S12);
-  result += assertEquals(a12, 0, 1e-13);
-  result += assertEquals(s12, 0, 1e-8);
-  result += assertEquals(azi1, 0, 1e-13);
-  result += assertEquals(azi2, 180, 1e-13);
-  result += assertEquals(m12, 0, 1e-8);
-  result += assertEquals(M12, 1, 1e-15);
-  result += assertEquals(M21, 1, 1e-15);
-  result += assertEquals(S12, 127516405431022, 0.5);
+  result += checkEquals(a12, 0, 1e-13);
+  result += checkEquals(s12, 0, 1e-8);
+  result += checkEquals(azi1, 0, 1e-13);
+  result += checkEquals(azi2, 180, 1e-13);
+  result += checkEquals(m12, 0, 1e-8);
+  result += checkEquals(M12, 1, 1e-15);
+  result += checkEquals(M21, 1, 1e-15);
+  result += checkEquals(S12, 127516405431022, 0.5);
   /* An incapable line which can't take distance as input */
   geod_lineinit(&l, &g, 1, 2, 90, GEOD_LATITUDE);
   a12 = geod_genposition(&l, 0, 1000, 0, 0, 0, 0, 0, 0, 0, 0);
-  result += a12 == a12 ? 1 : 0;
+  result += checkNaN(a12);
   return result;
 }
 
@@ -742,23 +752,23 @@ static int Planimeter0() {
   geod_init(&g, wgs84_a, wgs84_f);
 
   planimeter(&g, pa, 4, &perimeter, &area);
-  result += assertEquals(perimeter, 631819.8745, 1e-4);
-  result += assertEquals(area, 24952305678.0, 1);
+  result += checkEquals(perimeter, 631819.8745, 1e-4);
+  result += checkEquals(area, 24952305678.0, 1);
 
   planimeter(&g, pb, 4, &perimeter, &area);
-  result += assertEquals(perimeter, 631819.8745, 1e-4);
-  result += assertEquals(area, -24952305678.0, 1);
+  result += checkEquals(perimeter, 631819.8745, 1e-4);
+  result += checkEquals(area, -24952305678.0, 1);
 
   planimeter(&g, pc, 4, &perimeter, &area);
-  result += assertEquals(perimeter, 627598.2731, 1e-4);
-  result += assertEquals(area, 24619419146.0, 1);
+  result += checkEquals(perimeter, 627598.2731, 1e-4);
+  result += checkEquals(area, 24619419146.0, 1);
 
   planimeter(&g, pd, 3, &perimeter, &area);
-  result += assertEquals(perimeter, 30022685, 1);
-  result += assertEquals(area, 63758202715511.0, 1);
+  result += checkEquals(perimeter, 30022685, 1);
+  result += checkEquals(area, 63758202715511.0, 1);
 
   polylength(&g, pd, 3, &perimeter);
-  result += assertEquals(perimeter, 20020719, 1);
+  result += checkEquals(perimeter, 20020719, 1);
 
   return result;
 }
@@ -771,8 +781,8 @@ static int Planimeter5() {
   int result = 0;
   geod_init(&g, wgs84_a, wgs84_f);
   planimeter(&g, points, 3, &perimeter, &area);
-  result += assertEquals(perimeter, 539297, 1);
-  result += assertEquals(area, 12476152838.5, 1);
+  result += checkEquals(perimeter, 539297, 1);
+  result += checkEquals(area, 12476152838.5, 1);
   return result;
 }
 
@@ -788,17 +798,17 @@ static int Planimeter6() {
   geod_init(&g, wgs84_a, wgs84_f);
 
   planimeter(&g, pa, 3, &perimeter, &area);
-  result += assertEquals(perimeter, 36026861, 1);
-  result += assertEquals(area, 0, 1);
+  result += checkEquals(perimeter, 36026861, 1);
+  result += checkEquals(area, 0, 1);
   planimeter(&g, pb, 3, &perimeter, &area);
-  result += assertEquals(perimeter, 36026861, 1);
-  result += assertEquals(area, 0, 1);
+  result += checkEquals(perimeter, 36026861, 1);
+  result += checkEquals(area, 0, 1);
   planimeter(&g, pc, 3, &perimeter, &area);
-  result += assertEquals(perimeter, 36026861, 1);
-  result += assertEquals(area, 0, 1);
+  result += checkEquals(perimeter, 36026861, 1);
+  result += checkEquals(area, 0, 1);
   planimeter(&g, pd, 3, &perimeter, &area);
-  result += assertEquals(perimeter, 36026861, 1);
-  result += assertEquals(area, 0, 1);
+  result += checkEquals(perimeter, 36026861, 1);
+  result += checkEquals(area, 0, 1);
   return result;
 }
 
@@ -810,8 +820,8 @@ static int Planimeter12() {
   int result = 0;
   geod_init(&g, wgs84_a, wgs84_f);
   planimeter(&g, points, 2, &perimeter, &area);
-  result += assertEquals(perimeter, 10465729, 1);
-  result += assertEquals(area, 0, 1);
+  result += checkEquals(perimeter, 10465729, 1);
+  result += checkEquals(area, 0, 1);
   return result;
 }
 
@@ -824,8 +834,8 @@ static int Planimeter13() {
   int result = 0;
   geod_init(&g, wgs84_a, wgs84_f);
   planimeter(&g, points, 6, &perimeter, &area);
-  result += assertEquals(perimeter, 1160741, 1);
-  result += assertEquals(area, 32415230256.0, 1);
+  result += checkEquals(perimeter, 1160741, 1);
+  result += checkEquals(area, 32415230256.0, 1);
   return result;
 }
 
@@ -844,33 +854,33 @@ static int Planimeter15() {
   geod_polygon_addpoint(&g, &p, lat[0], lon[0]);
   geod_polygon_addpoint(&g, &p, lat[1], lon[1]);
   geod_polygon_testpoint(&g, &p, lat[2], lon[2], 0, 1, &area, 0);
-  result += assertEquals(area, r, 0.5);
+  result += checkEquals(area, r, 0.5);
   geod_polygon_testpoint(&g, &p, lat[2], lon[2], 0, 0, &area, 0);
-  result += assertEquals(area, r, 0.5);
+  result += checkEquals(area, r, 0.5);
   geod_polygon_testpoint(&g, &p, lat[2], lon[2], 1, 1, &area, 0);
-  result += assertEquals(area, -r, 0.5);
+  result += checkEquals(area, -r, 0.5);
   geod_polygon_testpoint(&g, &p, lat[2], lon[2], 1, 0, &area, 0);
-  result += assertEquals(area, a0-r, 0.5);
+  result += checkEquals(area, a0-r, 0.5);
   geod_inverse(&g, lat[1], lon[1], lat[2], lon[2], &s12, &azi1, 0);
   geod_polygon_testedge(&g, &p, azi1, s12, 0, 1, &area, 0);
-  result += assertEquals(area, r, 0.5);
+  result += checkEquals(area, r, 0.5);
   geod_polygon_testedge(&g, &p, azi1, s12, 0, 0, &area, 0);
-  result += assertEquals(area, r, 0.5);
+  result += checkEquals(area, r, 0.5);
   geod_polygon_testedge(&g, &p, azi1, s12, 1, 1, &area, 0);
-  result += assertEquals(area, -r, 0.5);
+  result += checkEquals(area, -r, 0.5);
   geod_polygon_testedge(&g, &p, azi1, s12, 1, 0, &area, 0);
-  result += assertEquals(area, a0-r, 0.5);
+  result += checkEquals(area, a0-r, 0.5);
   geod_polygon_addpoint(&g, &p, lat[2], lon[2]);
   geod_polygon_compute(&g, &p, 0, 1, &area, 0);
-  result += assertEquals(area, r, 0.5);
+  result += checkEquals(area, r, 0.5);
   geod_polygon_compute(&g, &p, 0, 0, &area, 0);
-  result += assertEquals(area, r, 0.5);
+  result += checkEquals(area, r, 0.5);
   geod_polygon_compute(&g, &p, 1, 1, &area, 0);
-  result += assertEquals(area, -r, 0.5);
+  result += checkEquals(area, -r, 0.5);
   geod_polygon_compute(&g, &p, 1, 0, &area, 0);
-  result += assertEquals(area, a0-r, 0.5);
+  result += checkEquals(area, a0-r, 0.5);
   geod_polygonarea(&g, lat, lon, 3, &area, 0);
-  result += assertEquals(area, r, 0.5);
+  result += checkEquals(area, r, 0.5);
   return result;
 }
 
@@ -890,8 +900,8 @@ static int Planimeter19() {
   result += area == 0 ? 0 : 1;
   result += perim == 0 ? 0 : 1;
   geod_polygon_testedge(&g, &p, 90, 1000, 0, 1, &area, &perim);
-  result += area == area ? 1 : 0;
-  result += perim == perim ? 1 : 0;
+  result += checkNaN(area);
+  result += checkNaN(perim);
   geod_polygon_addpoint(&g, &p, 1, 1);
   geod_polygon_compute(&g, &p, 0, 1, &area, &perim);
   result += area == 0 ? 0 : 1;
@@ -902,7 +912,7 @@ static int Planimeter19() {
   geod_polygon_testpoint(&g, &p, 1, 1, 0, 1, 0, &perim);
   result += perim == 0 ? 0 : 1;
   geod_polygon_testedge(&g, &p, 90, 1000, 0, 1, 0, &perim);
-  result += perim == perim ? 1 : 0;
+  result += checkNaN(perim);
   geod_polygon_addpoint(&g, &p, 1, 1);
   geod_polygon_compute(&g, &p, 0, 1, 0, &perim);
   result += perim == 0 ? 0 : 1;
@@ -935,30 +945,30 @@ static int Planimeter21() {
     geod_polygon_addpoint(&g, &p, lat,  60);
     geod_polygon_addpoint(&g, &p, lat, 180);
     geod_polygon_testpoint(&g, &p, lat, -60, 0, 1, &area, 0);
-    if (i != 4) result += assertEquals(area,  i*r, 0.5);
+    if (i != 4) result += checkEquals(area,  i*r, 0.5);
     geod_polygon_testpoint(&g, &p, lat, -60, 0, 0, &area, 0);
-    if (i != 4) result += assertEquals(area,  i*r, 0.5);
+    if (i != 4) result += checkEquals(area,  i*r, 0.5);
     geod_polygon_testpoint(&g, &p, lat, -60, 1, 1, &area, 0);
-    if (i != 4) result += assertEquals(area, -i*r, 0.5);
+    if (i != 4) result += checkEquals(area, -i*r, 0.5);
     geod_polygon_testpoint(&g, &p, lat, -60, 1, 0, &area, 0);
-    result += assertEquals(area, -i*r + a0, 0.5);
+    result += checkEquals(area, -i*r + a0, 0.5);
     geod_polygon_testedge(&g, &p, a, s, 0, 1, &area, 0);
-    if (i != 4) result += assertEquals(area,  i*r, 0.5);
+    if (i != 4) result += checkEquals(area,  i*r, 0.5);
     geod_polygon_testedge(&g, &p, a, s, 0, 0, &area, 0);
-    if (i != 4) result += assertEquals(area,  i*r, 0.5);
+    if (i != 4) result += checkEquals(area,  i*r, 0.5);
     geod_polygon_testedge(&g, &p, a, s, 1, 1, &area, 0);
-    if (i != 4) result += assertEquals(area, -i*r, 0.5);
+    if (i != 4) result += checkEquals(area, -i*r, 0.5);
     geod_polygon_testedge(&g, &p, a, s, 1, 0, &area, 0);
-    result += assertEquals(area, -i*r + a0, 0.5);
+    result += checkEquals(area, -i*r + a0, 0.5);
     geod_polygon_addpoint(&g, &p, lat, -60);
     geod_polygon_compute(&g, &p, 0, 1, &area, 0);
-    if (i != 4) result += assertEquals(area,  i*r, 0.5);
+    if (i != 4) result += checkEquals(area,  i*r, 0.5);
     geod_polygon_compute(&g, &p, 0, 0, &area, 0);
-    if (i != 4) result += assertEquals(area,  i*r, 0.5);
+    if (i != 4) result += checkEquals(area,  i*r, 0.5);
     geod_polygon_compute(&g, &p, 1, 1, &area, 0);
-    if (i != 4) result += assertEquals(area, -i*r, 0.5);
+    if (i != 4) result += checkEquals(area, -i*r, 0.5);
     geod_polygon_compute(&g, &p, 1, 0, &area, 0);
-    result += assertEquals(area, -i*r + a0, 0.5);
+    result += checkEquals(area, -i*r + a0, 0.5);
   }
   return result;
 }
@@ -976,7 +986,7 @@ static int AddEdge1() {
   geod_polygon_addedge(&g, &p,   0, 1000);
   geod_polygon_addedge(&g, &p, -90, 1000);
   geod_polygon_compute(&g, &p, 0, 1, &area, 0);
-  result += assertEquals(area, 1000000.0, 0.01);
+  result += checkEquals(area, 1000000.0, 0.01);
   return result;
 }
 
@@ -991,8 +1001,8 @@ static int EmptyPoly() {
   result += area == 0 ? 0 : 1;
   result += perim == 0 ? 0 : 1;
   geod_polygon_testedge(&g, &p, 90, 1000, 0, 1, &area, &perim);
-  result += area == area ? 1 : 0;
-  result += perim == perim ? 1 : 0;
+  result += checkNaN(area);
+  result += checkNaN(perim);
   geod_polygon_compute(&g, &p, 0, 1, &area, &perim);
   result += area == 0 ? 0 : 1;
   result += perim == 0 ? 0 : 1;
@@ -1000,14 +1010,14 @@ static int EmptyPoly() {
   geod_polygon_testpoint(&g, &p, 1, 1, 0, 1, 0, &perim);
   result += perim == 0 ? 0 : 1;
   geod_polygon_testedge(&g, &p, 90, 1000, 0, 1, 0, &perim);
-  result += perim == perim ? 1 : 0;
+  result += checkNaN(perim);
   geod_polygon_compute(&g, &p, 0, 1, 0, &perim);
   result += perim == 0 ? 0 : 1;
   geod_polygon_addpoint(&g, &p, 1, 1);
   geod_polygon_testedge(&g, &p, 90, 1000, 0, 1, 0, &perim);
-  result += assertEquals(perim, 1000, 1e-10);
+  result += checkEquals(perim, 1000, 1e-10);
   geod_polygon_testpoint(&g, &p, 2, 2, 0, 1, 0, &perim);
-  result += assertEquals(perim, 156876.149, 0.5e-3);
+  result += checkEquals(perim, 156876.149, 0.5e-3);
   return result;
 }
 
