@@ -27,16 +27,19 @@
  * DEALINGS IN THE SOFTWARE.
  *****************************************************************************/
 
-
-
 #define PJ_LIB__
-#include "geodesic.h"
+
+#include <ctype.h>
+#include <errno.h>
+#include <math.h>
+#include <stddef.h>
 #include <stdio.h>
 #include <string.h>
-#include <errno.h>
-#include <ctype.h>
+
+#include "geodesic.h"
 #include "proj.h"
 #include "proj_internal.h"
+#include "proj_math.h"
 #include "projects.h"
 
 
@@ -67,6 +70,9 @@ static paralist *string_to_paralist (PJ_CONTEXT *ctx, char *definition) {
             c++;
     }
 
+    if( next == 0 )
+        return 0;
+
     /* Terminate list and return */
     next->next = 0;
     return first;
@@ -123,7 +129,9 @@ static char *get_init_string (PJ_CONTEXT *ctx, char *name) {
     *section = 0;
     section++;
     n = strlen (section);
-    pj_log (ctx, 3, "get_init_string: searching for section [%s] in init file [%s]\n", section, fname);
+    pj_log (ctx, PJ_LOG_TRACE,
+            "get_init_string: searching for section [%s] in init file [%s]",
+            section, fname);
 
     fid = pj_open_lib (ctx, fname, "rt");
     if (0==fid) {
@@ -213,7 +221,7 @@ static char *get_init_string (PJ_CONTEXT *ctx, char *name) {
     if (0==buffer)
         return 0;
     pj_shrink (buffer);
-    pj_log (ctx, 3, "key=%s, value: [%s]\n", key, buffer);
+    pj_log (ctx, PJ_LOG_TRACE, "key=%s, value: [%s]", key, buffer);
     return buffer;
 }
 
@@ -233,7 +241,7 @@ Expand key from buffer or (if not in buffer) from init file
         xkey = key;
     else
         xkey += 5;
-    pj_log (ctx, 3, "get_init: searching cache for key: [%s]\n", xkey);
+    pj_log (ctx, PJ_LOG_TRACE, "get_init: searching cache for key: [%s]", xkey);
 
     /* Is file/key pair already in cache? */
     init_items = pj_search_initcache (xkey);
@@ -241,13 +249,17 @@ Expand key from buffer or (if not in buffer) from init file
         return init_items;
 
     /* If not, we must read it from file */
-    pj_log (ctx, 3, "get_init: searching on in init files for [%s]\n", xkey);
+    pj_log (ctx, PJ_LOG_TRACE,
+            "get_init: searching on in init files for [%s]", xkey);
     definition = get_init_string (ctx, xkey);
     if (0==definition)
         return 0;
     init_items = string_to_paralist (ctx, definition);
     if (init_items)
-        pj_log (ctx, 3, "get_init: got [%s], paralist[0,1]: [%s,%s]\n", definition, init_items->param, init_items->next? init_items->next->param: "(empty)");
+        pj_log (ctx, PJ_LOG_TRACE, "get_init: got [%s], paralist[0,1]: [%s,%s]",
+                definition,
+                init_items->param,
+                init_items->next ? init_items->next->param : "(empty)");
     pj_dealloc (definition);
     if (0==init_items)
         return 0;
@@ -590,9 +602,10 @@ pj_init_ctx(projCtx ctx, int argc, char **argv) {
     /* Set datum parameters. Similarly to +init parameters we want to expand    */
     /* +datum parameters as late as possible when dealing with pipelines.       */
     /* otherwise only the first occurrence of +datum will be expanded and that */
-    if (n_pipelines == 0)
+    if (n_pipelines == 0) {
         if (pj_datum_set(ctx, start, PIN))
             return pj_default_destructor (PIN, proj_errno(PIN));
+    }
 
     err = pj_ellipsoid (PIN);
 
@@ -692,7 +705,7 @@ pj_init_ctx(projCtx ctx, int argc, char **argv) {
     if ((name = pj_param(ctx, start, "sunits").s) != NULL) {
         for (i = 0; (s = pj_units[i].id) && strcmp(name, s) ; ++i) ;
         if (!s)
-            return pj_default_destructor (PIN, PJD_ERR_UNKNOW_UNIT_ID);
+            return pj_default_destructor (PIN, PJD_ERR_UNKNOWN_UNIT_ID);
         s = pj_units[i].to_meter;
     }
     if (s || (s = pj_param(ctx, start, "sto_meter").s)) {
@@ -720,7 +733,7 @@ pj_init_ctx(projCtx ctx, int argc, char **argv) {
     if ((name = pj_param(ctx, start, "svunits").s) != NULL) {
         for (i = 0; (s = pj_units[i].id) && strcmp(name, s) ; ++i) ;
         if (!s)
-            return pj_default_destructor (PIN, PJD_ERR_UNKNOW_UNIT_ID);
+            return pj_default_destructor (PIN, PJD_ERR_UNKNOWN_UNIT_ID);
         s = pj_units[i].to_meter;
     }
     if (s || (s = pj_param(ctx, start, "svto_meter").s)) {
