@@ -25,10 +25,13 @@
  * DEALINGS IN THE SOFTWARE.
  *****************************************************************************/
 
-#include "proj.h"
-#include <projects.h>
-#include <string.h>
 #include <stdarg.h>
+#include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
+
+#include "proj.h"
+#include "projects.h"
 
 /************************************************************************/
 /*                          pj_stderr_logger()                          */
