@@ -28,9 +28,10 @@
 
 #define PJ_LIB__
 
-#include <projects.h>
+#include <stdio.h>
 #include <string.h>
-#include <math.h>
+
+#include "projects.h"
 
 /************************************************************************/
 /*                           pj_is_latlong()                            */
@@ -78,27 +79,27 @@ PJ *pj_latlong_from_proj( PJ *pj_in )
     if( pj_param(pj_in->ctx, pj_in->params, "tdatum").i )
     {
         got_datum = TRUE;
-        sprintf( defn+strlen(defn), " +datum=%s", 
+        sprintf( defn+strlen(defn), " +datum=%s",
                  pj_param(pj_in->ctx, pj_in->params,"sdatum").s );
     }
     else if( pj_param(pj_in->ctx, pj_in->params, "tellps").i )
     {
-        sprintf( defn+strlen(defn), " +ellps=%s", 
+        sprintf( defn+strlen(defn), " +ellps=%s",
                  pj_param(pj_in->ctx, pj_in->params,"sellps").s );
     }
     else if( pj_param(pj_in->ctx,pj_in->params, "ta").i )
     {
-        sprintf( defn+strlen(defn), " +a=%s", 
+        sprintf( defn+strlen(defn), " +a=%s",
                  pj_param(pj_in->ctx,pj_in->params,"sa").s );
-            
+
         if( pj_param(pj_in->ctx,pj_in->params, "tb").i )
-            sprintf( defn+strlen(defn), " +b=%s", 
+            sprintf( defn+strlen(defn), " +b=%s",
                      pj_param(pj_in->ctx,pj_in->params,"sb").s );
         else if( pj_param(pj_in->ctx,pj_in->params, "tes").i )
-            sprintf( defn+strlen(defn), " +es=%s", 
+            sprintf( defn+strlen(defn), " +es=%s",
                      pj_param(pj_in->ctx,pj_in->params,"ses").s );
         else if( pj_param(pj_in->ctx,pj_in->params, "tf").i )
-            sprintf( defn+strlen(defn), " +f=%s", 
+            sprintf( defn+strlen(defn), " +f=%s",
                      pj_param(pj_in->ctx,pj_in->params,"sf").s );
         else
         {
@@ -113,7 +114,7 @@ PJ *pj_latlong_from_proj( PJ *pj_in )
     }
     else
     {
-        pj_ctx_set_errno( pj_in->ctx, -13 );
+        pj_ctx_set_errno( pj_in->ctx, PJD_ERR_MAJOR_AXIS_NOT_GIVEN );
 
         return NULL;
     }
@@ -121,17 +122,17 @@ PJ *pj_latlong_from_proj( PJ *pj_in )
     if( !got_datum )
     {
         if( pj_param(pj_in->ctx,pj_in->params, "ttowgs84").i )
-            sprintf( defn+strlen(defn), " +towgs84=%s", 
+            sprintf( defn+strlen(defn), " +towgs84=%s",
                      pj_param(pj_in->ctx,pj_in->params,"stowgs84").s );
 
         if( pj_param(pj_in->ctx,pj_in->params, "tnadgrids").i )
-            sprintf( defn+strlen(defn), " +nadgrids=%s", 
+            sprintf( defn+strlen(defn), " +nadgrids=%s",
                      pj_param(pj_in->ctx,pj_in->params,"snadgrids").s );
     }
 
     /* copy over some other information related to ellipsoid */
     if( pj_param(pj_in->ctx,pj_in->params, "tR").i )
-        sprintf( defn+strlen(defn), " +R=%s", 
+        sprintf( defn+strlen(defn), " +R=%s",
                  pj_param(pj_in->ctx,pj_in->params,"sR").s );
 
     if( pj_param(pj_in->ctx,pj_in->params, "tR_A").i )
@@ -144,16 +145,16 @@ PJ *pj_latlong_from_proj( PJ *pj_in )
         sprintf( defn+strlen(defn), " +R_a" );
 
     if( pj_param(pj_in->ctx,pj_in->params, "tR_lat_a").i )
-        sprintf( defn+strlen(defn), " +R_lat_a=%s", 
+        sprintf( defn+strlen(defn), " +R_lat_a=%s",
                  pj_param(pj_in->ctx,pj_in->params,"sR_lat_a").s );
 
     if( pj_param(pj_in->ctx,pj_in->params, "tR_lat_g").i )
-        sprintf( defn+strlen(defn), " +R_lat_g=%s", 
+        sprintf( defn+strlen(defn), " +R_lat_g=%s",
                  pj_param(pj_in->ctx,pj_in->params,"sR_lat_g").s );
 
     /* copy over prime meridian */
     if( pj_param(pj_in->ctx,pj_in->params, "tpm").i )
-        sprintf( defn+strlen(defn), " +pm=%s", 
+        sprintf( defn+strlen(defn), " +pm=%s",
                  pj_param(pj_in->ctx,pj_in->params,"spm").s );
 
     return pj_init_plus_ctx( pj_in->ctx, defn );
@@ -172,7 +173,7 @@ void pj_get_spheroid_defn(projPJ defn, double *major_axis, double *eccentricity_
 {
 	if ( major_axis )
 		*major_axis = defn->a;
-		
+
 	if ( eccentricity_squared )
 		*eccentricity_squared = defn->es;
-};
+}
