@@ -503,12 +503,12 @@ Returns 1 on success, 0 on failure
         def = malloc (100+n);
         if (0==def)
             return 0;
-        sprintf (def, "break_cs2cs_recursion     proj=helmert exact %s transpose", s);
+        sprintf (def, "break_cs2cs_recursion     proj=helmert exact %s convention=position_vector", s);
         Q = proj_create (P->ctx, def);
-        pj_inherit_ellipsoid_def (P, Q);
-        free (def);
+        free(def);
         if (0==Q)
             return 0;
+        pj_inherit_ellipsoid_def (P, Q);
         P->helmert = skip_prep_fin (Q);
 
         break;
@@ -524,11 +524,13 @@ Returns 1 on success, 0 on failure
             return 0;
         P->cart = skip_prep_fin (Q);
 
-        sprintf (def, "break_cs2cs_recursion     proj=cart  ellps=WGS84");
-        Q = proj_create (P->ctx, def);
-        if (0==Q)
-            return 0;
-        P->cart_wgs84 = skip_prep_fin (Q);
+        if (!P->is_geocent) {
+            sprintf (def, "break_cs2cs_recursion     proj=cart  ellps=WGS84");
+            Q = proj_create (P->ctx, def);
+            if (0==Q)
+                return 0;
+            P->cart_wgs84 = skip_prep_fin (Q);
+        }
     }
 
     return 1;
@@ -558,13 +560,16 @@ PJ *proj_create (PJ_CONTEXT *ctx, const char *definition) {
     /* Make a copy that we can manipulate */
     n = strlen (definition);
     args = (char *) malloc (n + 1);
-    if (0==args)
+    if (0==args) {
+        proj_context_errno_set(ctx, ENOMEM);
         return 0;
+    }
     strcpy (args, definition);
 
     argc = pj_trim_argc (args);
     if (argc==0) {
         pj_dealloc (args);
+        proj_context_errno_set(ctx, PJD_ERR_NO_ARGS);
         return 0;
     }
 
@@ -598,15 +603,19 @@ indicator, as in {"+proj=utm", "+zone=32"}, or leave it out, as in {"proj=utm",
     PJ *P;
     const char *c;
 
-    if (0==argv)
-        return 0;
     if (0==ctx)
         ctx = pj_get_default_ctx ();
+    if (0==argv) {
+        proj_context_errno_set(ctx, PJD_ERR_NO_ARGS);
+        return 0;
+    }
 
     /* We assume that free format is used, and build a full proj_create compatible string */
     c = pj_make_args (argc, argv);
-    if (0==c)
+    if (0==c) {
+        proj_context_errno_set(ctx, ENOMEM);
         return 0;
+    }
 
     P = proj_create (ctx, c);
 
@@ -1019,7 +1028,7 @@ PJ_INIT_INFO proj_init_info(const char *initname){
 
     strncpy (key, initname, 64); /* make room for ":metadata\0" at the end */
     key[64] = 0;
-    strncat(key, ":metadata", 9);
+    memcpy(key + strlen(key), ":metadata", 9 + 1);
     strcpy(param, "+init=");
     /* The +strlen(param) avoids a cppcheck false positive warning */
     strncat(param + strlen(param), key, sizeof(param)-1-strlen(param));
