@@ -38,12 +38,13 @@
  *
 */
 
-
 #define PJ_LIB__
 
 #include <errno.h>
-#include <proj.h>
+
+#include "proj.h"
 #include "projects.h"
+#include "proj_math.h"
 
 
 struct pj_opaque {
@@ -62,32 +63,6 @@ PROJ_HEAD(utm, "Universal Transverse Mercator (UTM)")
 
 #define PROJ_ETMERC_ORDER 6
 
-
-#ifdef _GNU_SOURCE
-    inline
-#endif
-static double log1py(double x) {              /* Compute log(1+x) accurately */
-    volatile double
-      y = 1 + x,
-      z = y - 1;
-    /* Here's the explanation for this magic: y = 1 + z, exactly, and z
-     * approx x, thus log(y)/z (which is nearly constant near z = 0) returns
-     * a good approximation to the true log(1 + x)/x.  The multiplication x *
-     * (log(y)/z) introduces little additional error. */
-    return z == 0 ? x : x * log(y) / z;
-}
-
-
-#ifdef _GNU_SOURCE
-    inline
-#endif
-static double asinhy(double x) {              /* Compute asinh(x) accurately */
-    double y = fabs(x);         /* Enforce odd parity */
-    y = log1py(y * (1 + y/(hypot(1.0, y) + 1)));
-    return x < 0 ? -y : y;
-}
-
-
 #ifdef _GNU_SOURCE
     inline
 #endif
@@ -96,8 +71,13 @@ static double gatg(double *p1, int len_p1, double B) {
     double h = 0, h1, h2 = 0, cos_2B;
 
     cos_2B = 2*cos(2*B);
-    for (p = p1 + len_p1, h1 = *--p; p - p1; h2 = h1, h1 = h)
+    p = p1 + len_p1;
+    h1 = *--p;
+    while (p - p1) {
         h = -h2 + cos_2B*h1 + *--p;
+        h2 = h1;
+        h1 = h;
+    }
     return (B + h*sin(2*B));
 }
 
@@ -123,7 +103,9 @@ static double clenS(double *a, int size, double arg_r, double arg_i, double *R,
     i          = -2*sin_arg_r*sinh_arg_i;
 
     /* summation loop */
-    for (hi1 = hr1 = hi = 0, hr = *--p; a - p;) {
+    hi1 = hr1 = hi = 0;
+    hr = *--p;
+    for (; a - p;) {
         hr2 = hr1;
         hi2 = hi1;
         hr1 = hr;
@@ -149,7 +131,9 @@ static double clens(double *a, int size, double arg_r) {
     r          =  2*cos_arg_r;
 
     /* summation loop */
-    for (hr1 = 0, hr = *--p; a - p;) {
+    hr1 = 0;
+    hr = *--p;
+    for (; a - p;) {
         hr2 = hr1;
         hr1 = hr;
         hr  = -hr2 + r*hr1 + *--p;
@@ -182,7 +166,7 @@ static XY e_forward (LP lp, PJ *P) {          /* Ellipsoidal, forward */
     Ce     = atan2 (sin_Ce*cos_Cn,  hypot (sin_Cn, cos_Cn*cos_Ce));
 
     /* compl. sph. N, E -> ell. norm. N, E */
-    Ce  = asinhy ( tan (Ce) );     /* Replaces: Ce  = log(tan(FORTPI + Ce*0.5)); */
+    Ce  = asinh ( tan (Ce) );     /* Replaces: Ce  = log(tan(FORTPI + Ce*0.5)); */
     Cn += clenS (Q->gtu, PROJ_ETMERC_ORDER, 2*Cn, 2*Ce, &dCn, &dCe);
     Ce += dCe;
     if (fabs (Ce) <= 2.623395162778) {
@@ -335,7 +319,7 @@ PJ *PROJECTION(etmerc) {
 
 
 PJ *PROJECTION(utm) {
-    int zone;
+    long zone;
     struct pj_opaque *Q = pj_calloc (1, sizeof (struct pj_opaque));
     if (0==Q)
         return pj_default_destructor (P, ENOMEM);
@@ -345,6 +329,10 @@ PJ *PROJECTION(utm) {
         proj_errno_set(P, PJD_ERR_ELLIPSOID_USE_REQUIRED);
         return pj_default_destructor(P, ENOMEM);
     }
+    if (P->lam0 < -1000.0 || P->lam0 > 1000.0) {
+        return pj_default_destructor(P, PJD_ERR_INVALID_UTM_ZONE);
+    }
+
     P->y0 = pj_param (P->ctx, P->params, "bsouth").i ? 10000000. : 0.;
     P->x0 = 500000.;
     if (pj_param (P->ctx, P->params, "tzone").i) /* zone input ? */
@@ -358,7 +346,7 @@ PJ *PROJECTION(utm) {
     }
     else /* nearest central meridian input */
     {
-        zone = (int)(floor ((adjlon (P->lam0) + M_PI) * 30. / M_PI));
+        zone = lround((floor ((adjlon (P->lam0) + M_PI) * 30. / M_PI)));
         if (zone < 0)
             zone = 0;
         else if (zone >= 60)
@@ -370,4 +358,3 @@ PJ *PROJECTION(utm) {
 
     return setup (P);
 }
-
