@@ -28,7 +28,12 @@
 ** Precision commensurate with double precision.
 */
 #define PJ_LIB__
-#include <projects.h>
+
+#include <math.h>
+#include <stdlib.h>
+
+#include "projects.h"
+
 #define MAX_ITER 20
 #define TOL 1e-14
 
@@ -117,6 +122,6 @@ proj_inv_mdist(projCtx ctx, double dist, const void *data) {
 			return phi;
 	}
 		/* convergence failed */
-	pj_ctx_set_errno(ctx, -17);
+	pj_ctx_set_errno(ctx, PJD_ERR_NON_CONV_INV_MERI_DIST);
 	return phi;
 }
